==> nextcloud-30.0.17rc2.zip: nextcloud/apps/files_external/l10n/et_EE.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Anna ligipääs",
    "Error configuring OAuth2" : "Viga OAuth2 seadistamisel",
    "Generate keys" : "Loo võtmed",
    "Error generating key pair" : "Viga võtmepaari loomisel",
    "You are not logged in" : "Sa pole sisse logitud.",
    "Permission denied" : "Õigus on keelatud",
    "Forbidden to manage local mounts" : "Kohalike haakepunktide haldamine on  keelatud",
    "Storage with ID \"%d\" not found" : "Andmeruumi tunnusega „%d“ ei leidu",
    "Invalid backend or authentication mechanism class" : "Vigane taustateenus või autentimismeetodi klass",
    "Invalid mount point" : "Vigane haakepunkt",
    "Objectstore forbidden" : "Objectstore on keelatud",
    "Invalid storage backend \"%s\"" : "Vigane salvestuskoha taustsüsteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Pole luba kasutada „%s“ taustateenust",
    "Not permitted to use authentication mechanism \"%s\"" : "Pole luba kasutada „%s“ autentimismeetodit",
    "Unsatisfied backend parameters" : "Rahuldamata taustarakenduse parameetrid",
    "Unsatisfied authentication mechanism parameters" : "Autentimisviisi parameetrid pole tagatud",
    "Insufficient data: %s" : "Pole piisavalt andmeid: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Andmeruumi tunnusega „%d“ on muudetav vaid peakasutajate poolt",
    "Access key" : "Ligipääsuvõti",
    "Secret key" : "Salavõti",
    "Builtin" : "Sisseehitatud",
    "None" : "Pole",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi saladus",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Logi sisse",
    "Password" : "Salasõna",
    "Tenant name" : "Kliendi nimi",
    "Identity endpoint URL" : "Tuvastuse otspunkti võrguaadress",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domeen",
    "Rackspace" : "Rackspace",
    "API key" : "API võti",
    "Global credentials" : "Üldinekasutajanimi/salasõna",
    "Log-in credentials, save in database" : "Salvesta sisselogimise kasutajanimi/salasõna andmebaasi",
    "Login and password" : "Kasutajanimi ja salasõna",
    "Log-in credentials, save in session" : "Salvesta sisselogimise kasutajanimi/salasõna sessioonis",
    "Global credentials, manually entered" : "Käsitsi sisestatud üldine kasutajanimi/salasõna",
    "Manually entered, store in database" : "Käsitsi sisestatud ja salvestub andmebaasis",
    "RSA public key" : "RSA avalik võti",
    "Public key" : "Avalik võti",
    "RSA private key" : "RSA privaatvõti",
    "Private key" : "Privaatvõti",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberose nimi (realm), vaikimisi „WORKGROUP“",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korv",
    "Hostname" : "Hostinimi",
    "Port" : "Port",
    "Region" : "Piirkond",
    "Storage Class" : "Andmeruumi klass (Storage class)",
    "Enable SSL" : "SSL-i kasutamine",
    "Enable Path Style" : "Luba otsingtee stiilis",
    "Legacy (v2) authentication" : "Pärandvormis autentimine (v2)",
    "SSE-C encryption key" : "SSE-C krüptimisvõti",
    "WebDAV" : "WebDAV",
    "URL" : "Võrguaadress",
    "Remote subfolder" : "Mujal olev alamkaust",
    "Secure https://" : "Turvaline https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Turvaline ftps://",
    "Local" : "Kohalik",
    "Location" : "Asukoht",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juur",
    "SFTP with secret key login" : "SFTP koos salajase võtmega logimisega",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Jaga",
    "Show hidden files" : "Näita peidetud faile",
    "Case sensitive file system" : "Tõstutundlik failisüsteem",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Selle valiku keelamisega saad kasutada tõstutundetut failisüsteemi, kuid sellega kaasneb jõudluskadu",
    "Verify ACL access when listing files" : "Failide loendi kuvamisel kontrolli ka õiguste loendit",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Selle eelistusega kontrollitakse loendi koostamisel, kas kasutajal on antud failide või kaustade nägemiseks õigused olemas ja jäetakse välja need, kus pole. Palun arvesta, et sellega tekib jõudluskadu.",
    "Timeout" : "Aegumine",
    "SMB/CIFS using OC login" : "SMB / CIFS kasutades OC sisselogimist",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Teenuse nimi",
    "Request timeout (seconds)" : "Päringu aegumine (sekundites)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-i tugi on PHP-s on kas paigaldamata või pole kasutusele võetud. „%s“ haakimine pole võimalik. Palun oma peakasutajat, et ta teeks cURL-i toe tagamiseks vajalikud muudatused.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tugi on PHP-s on kas paigaldamata või pole kasutusele võetud. „%s“ haakimine pole võimalik. Palun oma peakasutajat, et ta teeks FTP toe tagamiseks vajalikud muudatused.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ pole paigladatud. „%2$s“ haakimine pole võimalik. Palu oma peakasutajal või süsteemihalduril ta paigaldada.",
    "External storage" : "Väline andmehoidla",
    "External storage support" : "Väliste andmehoidlate tugi",
    "Adds basic external storage support" : "Lisab väliste andmehoidlate toe põhivariandi",
    "Confirm" : "Kinnita",
    "Storage credentials" : "Andmeruumi kasutajanimi/salasõna",
    "To access the storage, you need to provide the authentication credentials." : "Selle andmeruumi jaoks pead autentimiseks lisama kasutajanime ja salasõna.",
    "Enter the storage login" : "Sisesta andmeruumi kasutajatunnus",
    "Enter the storage password" : "Sisesta andmeruumi kasutaja salasõna",
    "Unable to update this external storage config. {statusMessage}" : "Selle välise andmeruumi seadistusi pole võimalik uuendada. {statusMessage}",
    "New configuration successfully saved" : "Uue seadistuse salvestamine õnnestus",
    "Enter missing credentials" : "Lisa puuduvad kasutajanimi/salasõna",
    "Credentials successfully set" : "Kasutajanime/salasõna lisamine õnnestus",
    "Error while setting credentials: {error}" : "Viga kasutajanime/salasõna lisamisel: {error}",
    "There was an error with this external storage." : "Selle välis andmeruumi kontekstis tekkis viga.",
    "We were unable to check the external storage {basename}" : "Meil ei õnnestunud kontrollida välist andmeruumi „{basename}“",
    "Examine this faulty external storage configuration" : "Kontrolli uuesti selle vigase välise andmeruumi seadistusi",
    "Open in Files" : "Ava failirakenduses",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Selle välise andmeruumiga tekkis viga. Kas sa tahaksid seadistustest kontrollida haakepunkti konfiguratsiooni?",
    "External mount error" : "Viga välise andmeruumi haakimisel",
    "List of external storage." : "Väliste andmeruumide loend.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Ühtegi välist andmeruumi pole seadistatud. Saad seda teha isiklikest seadistustest.",
    "There is no external storage configured and you don't have the permission to configure them." : "Ühtegi välist andmeruumi pole seadistatud ja sul pole õigust seda teha.",
    "No external storage" : "Ühtegi välist andmeruumi ei leidu",
    "Storage type" : "Andmeruumi tüüp",
    "Unknown" : "Teadmata",
    "Scope" : "Skoop",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Type to select account or group." : "Kasutakonto või grupi leidmiseks kirjuta midagi.",
    "(Group)" : "(Grupp)",
    "Compatibility with Mac NFD encoding (slow)" : "Ühilduvus Mac NFD kodeeringuga (aeglane)",
    "Enable encryption" : "Luba krüptimine",
    "Enable previews" : "Luba eelvaated",
    "Enable sharing" : "Luba jagamine",
    "Check for changes" : "Otsi uuendusi",
    "Never" : "Mitte kunagi",
    "Once every direct access" : "Kord iga otsese pöördumise korral",
    "Read only" : "kirjutuskaitstud",
    "Disconnect" : "Ühenda lahti",
    "Unknown backend: {backendName}" : "Tundmatu taustateenus: {backendName}",
    "Admin defined" : "Admini poolt määratud",
    "Are you sure you want to disconnect this external storage?" : "Kas sa oled kindel, et soovid katkestada ühenduse selle välise andmeruumiga?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Sellega muutub see andmeruum teenuses „{instanceName}“ kättesaadamatuks ning kustuvad kõikide hetkel ühendatud sünkroonimisklientide juurest vastavad kaustad ja failid. Aga sellega ei kustu need kaustad ja failid antud välisest andmeruumist endast.",
    "Delete storage?" : "Kas kustutame andmeruumi?",
    "Click to recheck the configuration" : "Klõpsi seadistuste uuesti kontrollimiseks",
    "Saved" : "Salvestatud",
    "Saving …" : "Salvestan…",
    "Save" : "Salvesta",
    "Failed to save global credentials" : "Üldise kasutajanime/salasõna salvestamine ei õnnestunud",
    "Failed to save global credentials: {message}" : "Üldise kasutajanime/salasõna salvestamine ei õnnestunud: {message}",
    "Open documentation" : "Ava dokumentatsioon",
    "Folder name" : "Kausta nimi",
    "Authentication" : "Autentimine",
    "Configuration" : "Seadistamine",
    "Available for" : "Saadaval",
    "Add storage" : "Lisa andmehoidla",
    "All people" : "Kõik inimesed",
    "Advanced settings" : "Lisavalikud",
    "Allow people to mount external storage" : "Luba kõigil haakida välist andmeruumi",
    "Error configuring OAuth1" : "Viga OAuth1 seadistamisel",
    "Please provide a valid app key and secret." : "Palun sisesta rakenduse kehtiv võti ja saladus.",
    "OAuth1" : "OAuth1",
    "App key" : "Rakenduse võti",
    "App secret" : "Rakenduse salasõna",
    "Checking storage …" : "Kontrollin andmeruumi…",
    "Saving …" : "Salvestan…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11rc2.zip: nextcloud/apps/files_external/l10n/et_EE.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Anna ligipääs",
    "Error configuring OAuth2" : "Viga OAuth2 seadistamisel",
    "Generate keys" : "Loo võtmed",
    "Error generating key pair" : "Viga võtmepaari loomisel",
    "You are not logged in" : "Sa pole sisse logitud.",
    "Permission denied" : "Õigus on keelatud",
    "Forbidden to manage local mounts" : "Kohalike haakepunktide haldamine on  keelatud",
    "Storage with ID \"%d\" not found" : "Andmeruumi tunnusega „%d“ ei leidu",
    "Invalid backend or authentication mechanism class" : "Vigane taustateenus või autentimismeetodi klass",
    "Invalid mount point" : "Vigane haakepunkt",
    "Objectstore forbidden" : "Objectstore on keelatud",
    "Invalid storage backend \"%s\"" : "Vigane salvestuskoha taustsüsteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Pole luba kasutada „%s“ taustateenust",
    "Not permitted to use authentication mechanism \"%s\"" : "Pole luba kasutada „%s“ autentimismeetodit",
    "Unsatisfied backend parameters" : "Rahuldamata taustarakenduse parameetrid",
    "Unsatisfied authentication mechanism parameters" : "Autentimisviisi parameetrid pole tagatud",
    "Insufficient data: %s" : "Pole piisavalt andmeid: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Andmeruumi tunnusega „%d“ on muudetav vaid peakasutajate poolt",
    "Access key" : "Ligipääsuvõti",
    "Secret key" : "Salavõti",
    "Builtin" : "Sisseehitatud",
    "None" : "Pole",
    "OAuth2" : "OAuth2",
    "Client ID" : "Kliendi ID",
    "Client secret" : "Kliendi saladus",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Kasutajanimi",
    "Password" : "Salasõna",
    "Tenant name" : "Kliendi nimi",
    "Identity endpoint URL" : "Tuvastuse otspunkti võrguaadress",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domeen",
    "Rackspace" : "Rackspace",
    "API key" : "API võti",
    "Global credentials" : "Üldinekasutajanimi/salasõna",
    "Log-in credentials, save in database" : "Salvesta sisselogimise kasutajanimi/salasõna andmebaasi",
    "Login and password" : "Kasutajanimi ja salasõna",
    "Log-in credentials, save in session" : "Salvesta sisselogimise kasutajanimi/salasõna sessioonis",
    "Global credentials, manually entered" : "Käsitsi sisestatud üldine kasutajanimi/salasõna",
    "Manually entered, store in database" : "Käsitsi sisestatud ja salvestub andmebaasis",
    "RSA public key" : "RSA avalik võti",
    "Public key" : "Avalik võti",
    "RSA private key" : "RSA privaatvõti",
    "Private key" : "Privaatvõti",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberose nimi (realm), vaikimisi „WORKGROUP“",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Korv",
    "Hostname" : "Hostinimi",
    "Port" : "Port",
    "Region" : "Piirkond",
    "Storage Class" : "Andmeruumi klass (Storage class)",
    "Enable SSL" : "SSL-i kasutamine",
    "Enable Path Style" : "Luba otsingtee stiilis",
    "Legacy (v2) authentication" : "Pärandvormis autentimine (v2)",
    "Enable multipart copy" : "Luba mitmeosaline kopeerimine",
    "SSE-C encryption key" : "SSE-C krüptimisvõti",
    "WebDAV" : "WebDAV",
    "URL" : "Võrguaadress",
    "Remote subfolder" : "Mujal olev alamkaust",
    "Secure https://" : "Turvaline https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Turvaline ftps://",
    "Local" : "Kohalik",
    "Location" : "Asukoht",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Juur",
    "SFTP with secret key login" : "SFTP koos salajase võtmega logimisega",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Jaga",
    "Show hidden files" : "Näita peidetud faile",
    "Case sensitive file system" : "Tõstutundlik failisüsteem",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Selle valiku keelamisega saad kasutada tõstutundetut failisüsteemi, kuid sellega kaasneb jõudluskadu",
    "Verify ACL access when listing files" : "Failide loendi kuvamisel kontrolli ka õiguste loendit",
    "Check the ACL's of each file or folder inside a directory to filter out items where the account has no read permissions, comes with a performance penalty" : "Selle eelistusega kontrollitakse loendi koostamisel, kas kasutajal on antud failide või kaustade nägemiseks õigused olemas ja jäetakse välja need, kus pole. Palun arvesta, et sellega tekib jõudluskadu.",
    "Timeout" : "Aegumine",
    "SMB/CIFS using OC login" : "SMB / CIFS kasutades OC sisselogimist",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Teenuse nimi",
    "Request timeout (seconds)" : "Päringu aegumine (sekundites)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-i tugi on PHP-s on kas paigaldamata või pole kasutusele võetud. „%s“ haakimine pole võimalik. Palun oma peakasutajat, et ta teeks cURL-i toe tagamiseks vajalikud muudatused.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tugi on PHP-s on kas paigaldamata või pole kasutusele võetud. „%s“ haakimine pole võimalik. Palun oma peakasutajat, et ta teeks FTP toe tagamiseks vajalikud muudatused.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "„%1$s“ pole paigladatud. „%2$s“ haakimine pole võimalik. Palu oma peakasutajal või süsteemihalduril ta paigaldada.",
    "External storage" : "Väline andmehoidla",
    "External storage support" : "Väliste andmehoidlate tugi",
    "Adds basic external storage support" : "Lisab väliste andmehoidlate toe põhivariandi",
    "Confirm" : "Kinnita",
    "Storage credentials" : "Andmeruumi kasutajanimi/salasõna",
    "To access the storage, you need to provide the authentication credentials." : "Selle andmeruumi jaoks pead autentimiseks lisama kasutajanime ja salasõna.",
    "Enter the storage login" : "Sisesta andmeruumi kasutajatunnus",
    "Enter the storage password" : "Sisesta andmeruumi kasutaja salasõna",
    "Unable to update this external storage config. {statusMessage}" : "Selle välise andmeruumi seadistusi pole võimalik uuendada. {statusMessage}",
    "New configuration successfully saved" : "Uue seadistuse salvestamine õnnestus",
    "Enter missing credentials" : "Lisa puuduvad kasutajanimi/salasõna",
    "Credentials successfully set" : "Kasutajanime/salasõna lisamine õnnestus",
    "Error while setting credentials: {error}" : "Viga kasutajanime/salasõna lisamisel: {error}",
    "Checking storage …" : "Kontrollin andmeruumi…",
    "There was an error with this external storage." : "Selle välis andmeruumi kontekstis tekkis viga.",
    "We were unable to check the external storage {basename}" : "Meil ei õnnestunud kontrollida välist andmeruumi „{basename}“",
    "Examine this faulty external storage configuration" : "Kontrolli uuesti selle vigase välise andmeruumi seadistusi",
    "Open in Files" : "Ava failirakenduses",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Selle välise andmeruumiga tekkis viga. Kas sa tahaksid seadistustest kontrollida haakepunkti konfiguratsiooni?",
    "External mount error" : "Viga välise andmeruumi haakimisel",
    "List of external storage." : "Väliste andmeruumide loend.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Ühtegi välist andmeruumi pole seadistatud. Saad seda teha isiklikest seadistustest.",
    "There is no external storage configured and you don't have the permission to configure them." : "Ühtegi välist andmeruumi pole seadistatud ja sul pole õigust seda teha.",
    "No external storage" : "Ühtegi välist andmeruumi ei leidu",
    "Storage type" : "Andmeruumi tüüp",
    "Unknown" : "Teadmata",
    "Scope" : "Skoop",
    "Personal" : "Isiklik",
    "System" : "Süsteem",
    "Type to select account or group." : "Kasutakonto või grupi leidmiseks kirjuta midagi.",
    "(Group)" : "(Grupp)",
    "Compatibility with Mac NFD encoding (slow)" : "Ühilduvus Mac NFD kodeeringuga (aeglane)",
    "Enable encryption" : "Luba krüptimine",
    "Enable previews" : "Luba eelvaated",
    "Enable sharing" : "Luba jagamine",
    "Check for changes" : "Otsi uuendusi",
    "Never" : "Mitte kunagi",
    "Once every direct access" : "Kord iga otsese pöördumise korral",
    "Read only" : "kirjutuskaitstud",
    "Disconnect" : "Ühenda lahti",
    "Unknown backend: {backendName}" : "Tundmatu taustateenus: {backendName}",
    "Admin defined" : "Admini poolt määratud",
    "Are you sure you want to disconnect this external storage?" : "Kas sa oled kindel, et soovid katkestada ühenduse selle välise andmeruumiga?",
    "It will make the storage unavailable in {instanceName} and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Sellega muutub see andmeruum teenuses „{instanceName}“ kättesaadamatuks ning kustuvad kõikide hetkel ühendatud sünkroonimisklientide juurest vastavad kaustad ja failid. Aga sellega ei kustu need kaustad ja failid antud välisest andmeruumist endast.",
    "Delete storage?" : "Kas kustutame andmeruumi?",
    "Click to recheck the configuration" : "Klõpsi seadistuste uuesti kontrollimiseks",
    "Saved" : "Salvestatud",
    "Saving …" : "Salvestan…",
    "Save" : "Salvesta",
    "Failed to save global credentials" : "Üldise kasutajanime/salasõna salvestamine ei õnnestunud",
    "Failed to save global credentials: {message}" : "Üldise kasutajanime/salasõna salvestamine ei õnnestunud: {message}",
    "Open documentation" : "Ava dokumentatsioon",
    "Folder name" : "Kausta nimi",
    "Authentication" : "Autentimine",
    "Configuration" : "Seadistamine",
    "Available for" : "Saadaval",
    "Add storage" : "Lisa andmehoidla",
    "All people" : "Kõik inimesed",
    "Advanced settings" : "Lisavalikud",
    "Allow people to mount external storage" : "Luba kõigil haakida välist andmeruumi",
    "Error configuring OAuth1" : "Viga OAuth1 seadistamisel",
    "Please provide a valid app key and secret." : "Palun sisesta rakenduse kehtiv võti ja saladus.",
    "OAuth1" : "OAuth1",
    "App key" : "Rakenduse võti",
    "App secret" : "Rakenduse salasõna",
    "Checking storage …" : "Kontrollin andmeruumi…",
    "Saving …" : "Salvestan…"
},
"nplurals=2; plural=(n != 1);");
